==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/STRATEGYRANKINGSURVEYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour STRATEGYRANKINGSURVEYID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="STRATEGYRANKINGSURVEYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STRATEGYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGLEVELPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STRATEGYRANKINGSURVEYID_Type", propOrder = {
    "strategyid",
    "reliabilityrankinglevelpk"
})
public class STRATEGYRANKINGSURVEYID_Type {

    @XmlElement(name = "STRATEGYID", required = true)
    protected STRATEGYID_Type strategyid;
    @XmlElement(name = "RELIABILITYRANKINGLEVELPK", required = true)
    protected String reliabilityrankinglevelpk;

    /**
     * Obtient la valeur de la propriété strategyid.
     * 
     * @return
     *     possible object is
     *     {@link STRATEGYID_Type }
     *     
     */
    public STRATEGYID_Type getSTRATEGYID() {
        return strategyid;
    }

    /**
     * Définit la valeur de la propriété strategyid.
     * 
     * @param value
     *     allowed object is
     *     {@link STRATEGYID_Type }
     *     
     */
    public void setSTRATEGYID(STRATEGYID_Type value) {
        this.strategyid = value;
    }

    /**
     * Obtient la valeur de la propriété reliabilityrankinglevelpk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGLEVELPK() {
        return reliabilityrankinglevelpk;
    }

    /**
     * Définit la valeur de la propriété reliabilityrankinglevelpk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGLEVELPK(String value) {
        this.reliabilityrankinglevelpk = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/STRATEGYRANKINGSURVEYID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for STRATEGYRANKINGSURVEYID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="STRATEGYRANKINGSURVEYID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STRATEGYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELIABILITYRANKINGLEVELPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "STRATEGYRANKINGSURVEYID_Type", propOrder = {
    "strategyid",
    "reliabilityrankinglevelpk"
})
public class STRATEGYRANKINGSURVEYID_Type {

    @XmlElement(name = "STRATEGYID", required = true)
    protected STRATEGYID_Type strategyid;
    @XmlElement(name = "RELIABILITYRANKINGLEVELPK", required = true)
    protected String reliabilityrankinglevelpk;

    /**
     * Gets the value of the strategyid property.
     * 
     * @return
     *     possible object is
     *     {@link STRATEGYID_Type }
     *     
     */
    public STRATEGYID_Type getSTRATEGYID() {
        return strategyid;
    }

    /**
     * Sets the value of the strategyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STRATEGYID_Type }
     *     
     */
    public void setSTRATEGYID(STRATEGYID_Type value) {
        this.strategyid = value;
    }

    /**
     * Gets the value of the reliabilityrankinglevelpk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRELIABILITYRANKINGLEVELPK() {
        return reliabilityrankinglevelpk;
    }

    /**
     * Sets the value of the reliabilityrankinglevelpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRELIABILITYRANKINGLEVELPK(String value) {
        this.reliabilityrankinglevelpk = value;
    }

}
